#
# spec file for package gdm-branding-openSUSE
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define gdm_version %(rpm -q --qf '%%{version}' gdm)
Name:           gdm-branding-openSUSE
Version:        15.1
Release:        3.1
Summary:        The GNOME Display Manager -- openSUSE default configuration
License:        GPL-2.0-or-later
Group:          System/GUI/GNOME
URL:            http://projects.gnome.org/gdm/
Source99:       gdm-branding-openSUSE-rpmlintrc
# For directory ownership:
BuildRequires:  gdm
# To be in sync with upstream defaults, do branding as a patch for upstream file.
# WARNING: As this package conflicts with gdm-branding-openSUSE, you cannot
#          reuse build root. You have to build in a clean build root every time!
BuildRequires:  gdm-branding-upstream
%if 0%{?sle_version} >= 120300
BuildRequires:  sed
%endif
BuildRequires:  distribution-logos-openSUSE-Tumbleweed
Requires:       distribution-logos
Requires:       gdm
Supplements:    (gdm and branding-openSUSE)
Conflicts:      gdm-branding
Provides:       gdm-branding
BuildArch:      noarch

%description
The GNOME Display Manager is a system service that is responsible for
providing graphical log-ins and managing local and remote displays.

This package provides the openSUSE default configuration for gdm.

%prep
cp -a %{_sysconfdir}/gdm/custom.conf .

%build

%install
mkdir -p %{buildroot}%{_datadir}/gdm/greeter/images/
install -d %{buildroot}%{_sysconfdir}/gdm
install -m0644 custom.conf %{buildroot}%{_sysconfdir}/gdm/custom.conf
%if (!0%{?is_opensuse} && 0%{?sle_version} >= 120300) || (0%{?is_opensuse} && 0%{?sle_version} <= 150400 && 0%{?sle_version} >= 120300)
sed -i -e "s/\[daemon\]/\[daemon\]\nInitialSetupEnable=False/g" %{buildroot}%{_sysconfdir}/gdm/custom.conf
%endif
ln -sf %{_datadir}/pixmaps/distribution-logos/light-inline.svg %{buildroot}%{_datadir}/gdm/greeter/images/distributor.svg

%files
%config(noreplace) %{_sysconfdir}/gdm/custom.conf
%{_datadir}/gdm/greeter/images/distributor.svg
%dir %{_datadir}/gdm/greeter/images/

%changelog
* Thu Jan 19 2023 Yifan Jiang <yfjiang@suse.com>
- Bring back gnome-initial-setup for Leap 15.5 while keep it
  disabled on SLE 15 SP5 (jsc#PED-1719).
* Sun Apr 14 2019 Stasiek Michalski <hellcp@mailbox.org>
- Use new distribution-logos for the logo
* Wed Apr  3 2019 Stasiek Michalski <hellcp@mailbox.org>
- Adjust to new plymouth imagery
- 15.1
* Tue Mar 27 2018 yfjiang@suse.com
- Append InitialSetupEnable=False in custom.conf on Leap, disabling
  the gnome-initial-setup gdm mode, making it consistent with the
  behavior of SLE (bsc#1067976 boo#1086056).
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Sun Jan 29 2017 zaitor@opensuse.org
- No longer Require exact version of gdm, nor provide exact version
  of branding, it is not stricly needed, and only leads to issues
  with stable updates.
- Add gdm-branding-openSUSE-rpmlintrc as source: Filter out
  rpmlintwarning about exact version Provides.
- Drop obsolete gnome2-SuSE Obsoletes: No current version of
  openSUSE nor SLE have this package anymore.
- Drop obsolete clean section.
- Bump version to 42.3, to prepare for next version of openSUSE.
* Mon Oct 12 2015 zaitor@opensuse.org
- Bump version to 42.1, to prepare for next version of openSUSE.
* Sat Aug 23 2014 zaitor@opensuse.org
- Bump version to 13.2, to prepare for next version of openSUSE.
* Sun Sep  8 2013 zaitor@opensuse.org
- Bump version to 13.1, to prepare for next version of openSUSE.
* Mon Jun  4 2012 rbrownccb@opensuse.org
- Add banner logo for gdm login screen.
* Wed May 23 2012 vuntz@opensuse.org
- Bump version to 12.2, to prepare for next version of openSUSE.
* Thu Oct 13 2011 vuntz@opensuse.org
- Remove %%{release} from the gdm versioned Requires, to not have to
  rebuild this package each time gdm rebuilds to keep it
  installable.
* Thu Jul  7 2011 vuntz@opensuse.org
- Change License tag from BSD3c to GPLv2+: since we base our
  branding on the one from upstream, we inherit the license.
* Wed Jul  6 2011 vuntz@opensuse.org
- Bump version to 12.1.
- Add a Requires for gdm, since the branding package is useless
  without it.
- Update summary and description.
- Add Url tag.
* Wed Feb  2 2011 vuntz@opensuse.org
- Bump version to 11.4.
- Provide the right version of gdm-branding.
- Update description.
* Mon Oct 27 2008 vuntz@novell.com
- Completely rework the package to work with the new GDM.
  Fix bnc#436431.
- The only change we do compared to upstream is the logo on the
  greeter.
* Mon Oct  6 2008 sbrabec@suse.cz
- Conflict with other branding providers (FATE#304881).
* Thu May 29 2008 sbrabec@suse.cz
- Use Gilouche theme instead of Industrial (bnc#391865).
* Tue May  6 2008 sbrabec@suse.cz
- Obsolete conflicting gnome2-SuSE.
* Mon Apr 21 2008 sbrabec@suse.cz
- Call %%suse_update_desktop_file (bnc#380741).
* Wed Apr 16 2008 sbrabec@suse.cz
- New SuSE package (bnc#369317, fate#301792).
- New background color (bnc#361234).
